@@ -58,32 +58,9 @@ class __Anchor(__Assertion):
         super().__init__(str(transform(__class__._to_pregex(pre))))
 
 
-class __PositiveLookaround(__Assertion):
+class __Lookaround(__Assertion):
     '''
-    Constitutes the base class for classes ``FollowedBy`` and ``PrecededBy`` \
-        that are part of this module.
-
-    :param Pregex | str match: A Pregex instance or string representing the `match` pattern.
-    :param Pregex | str assertion: A Pregex instance or string representing the `assertion` pattern.
-    :param (Pregex, Pregex => str) transform: A `transform` function for the provided patterns.
-    '''
-    def __init__(self, match: _Union[_pre.Pregex, str], assertion: _Union[_pre.Pregex, str], transform):
-        '''
-        Constitutes the base class for classes ``FollowedBy`` and ``PrecededBy`` \
-            that are part of this module.
-
-        :param Pregex | str match: A Pregex instance or string representing the `match` pattern.
-        :param Pregex | str assertion: A Pregex instance or string representing the `assertion` pattern.
-        :param (Pregex, Pregex => str) transform: A `transform` function for the provided patterns.
-        '''
-        match = __class__._to_pregex(match)
-        super().__init__(str(transform(match, assertion)))
-
-
-class __NegativeLookaround(__Assertion):
-    '''
-    Constitutes the base class for classes ``NotFollowedBy`` and ``NotPrecededBy`` \
-        that are part of this module.
+    Constitutes the base class for all "Lookaround" classes.
 
     :param Pregex | str pres: Two or more Pregex instances, the first of which always \
         represents the `match` pattern, while the rest constitute `assertion` patterns.
@@ -95,8 +72,7 @@ class __NegativeLookaround(__Assertion):
     '''
     def __init__(self, pres: tuple[_Union[_pre.Pregex, str]], transform) -> _pre.Pregex:
         '''
-        Constitutes the base class for classes ``NotFollowedBy`` and ``NotPrecededBy`` \
-            that are part of this module.
+        Constitutes the base class for all "Lookaround" classes.
 
         :param Pregex | str pres: Two or more Pregex instances, the first of which always \
             represents the `match` pattern, while the rest constitute `assertion` patterns.
@@ -117,7 +93,7 @@ class __NegativeLookaround(__Assertion):
 
 class MatchAtStart(__Anchor):
     '''
-    Matches the provided pattern only if said pattern is at the start of the string.
+    Matches the provided pattern only if it is at the start of the string.
 
     :param Pregex | str pre: The pattern that is to be matched.
 
@@ -129,7 +105,7 @@ class MatchAtStart(__Anchor):
 
     def __init__(self, pre: _Union[_pre.Pregex, str]):
         '''
-        Matches the provided pattern only if said pattern is at the start of the string.
+        Matches the provided pattern only if it is at the start of the string.
 
         :param Pregex | str pre: The pattern that is to be matched.
 
@@ -143,7 +119,7 @@ class MatchAtStart(__Anchor):
 
 class MatchAtEnd(__Anchor):
     '''
-    Matches the provided pattern only if said pattern is at the end of the string.
+    Matches the provided pattern only if it is at the end of the string.
 
     :param Pregex | str pre: The pattern that is to be matched.
 
@@ -155,7 +131,7 @@ class MatchAtEnd(__Anchor):
 
     def __init__(self, pre: _Union[_pre.Pregex, str]):
         '''
-        Matches the provided pattern only if said pattern is at the end of the string.
+        Matches the provided pattern only if it is at the end of the string.
 
         :param Pregex | str pre: The pattern that is to be matched.
 
@@ -169,7 +145,7 @@ class MatchAtEnd(__Anchor):
 
 class MatchAtLineStart(__Anchor):
     '''
-    Matches the provided pattern only if said pattern is at the start of a line.
+    Matches the provided pattern only if it is at the start of a line.
 
     :param Pregex | str pre: The pattern that is to be matched.
 
@@ -183,7 +159,7 @@ class MatchAtLineStart(__Anchor):
 
     def __init__(self, pre: _Union[_pre.Pregex, str]):
         '''
-        Matches the provided pattern only if said pattern is at the end of the string.
+        Matches the provided pattern only if it is at the start of a line.
 
         :param Pregex | str pre: The pattern that is to be matched.
 
@@ -199,7 +175,7 @@ class MatchAtLineStart(__Anchor):
 
 class MatchAtLineEnd(__Anchor):
     '''
-    Matches the provided pattern only if said pattern is at the end of a line.
+    Matches the provided pattern only if it is at the end of a line.
 
     :param Pregex | str pre: The pattern that is to be matched.
 
@@ -213,7 +189,7 @@ class MatchAtLineEnd(__Anchor):
 
     def __init__(self, pre: _Union[_pre.Pregex, str]):
         '''
-        Matches the provided pattern only if said pattern is at the end of a line.
+        Matches the provided pattern only if it is at the end of a line.
 
         :param Pregex | str pre: The pattern that is to be matched.
 
@@ -238,7 +214,7 @@ class WordBoundary(__Anchor):
         Asserts that the position, at which an instance of this class is placed, \
         must constitute a word boundary.
         '''
-        super().__init__(_pre.Empty(), lambda pre: pre.concat(_pre.Pregex("\\b", escape=False)))
+        super().__init__(_pre.Pregex(), lambda pre: pre.concat(_pre.Pregex("\\b", escape=False)))
 
 
 class NonWordBoundary(__Anchor):
@@ -252,53 +228,56 @@ class NonWordBoundary(__Anchor):
         Asserts that the position, at which an instance of this class is placed, \
         must not constitute a word boundary.
         '''
-        super().__init__(_pre.Empty(), lambda pre: pre.concat(_pre.Pregex("\\B", escape=False)))
+        super().__init__(_pre.Pregex(), lambda pre: pre.concat(_pre.Pregex("\\B", escape=False)))
 
 
-class FollowedBy(__PositiveLookaround):
+class FollowedBy(__Lookaround):
     '''
-    Matches pattern ``match`` only if it is followed by pattern \
-    ``assertion``, without the latter being included into the match.
+    Matches pattern ``match`` only if it is directly followed \
+    by all of the provided ``assertion`` patterns.
 
     :param Pregex | str match: A Pregex instance or string \
         representing the `match` pattern.
-    :param Pregex | str assertion: A Pregex instance or string \
-        representing the `assertion` pattern.
+    :param Pregex | str \*assertions: One or more patterns, all of which must \
+        come right after pattern ``match`` in order for it to be considered a match.
 
+    :raises NotEnoughArgumentsException: No assertion patterns were provided.
     :raises InvalidArgumentTypeException: At least one of the provided arguments \
         is neither a ``Pregex`` instance nor a string.
 
     :note: The resulting pattern cannot have a repeating quantifier applied to it.
     '''
 
-    def __init__(self, match: _Union[_pre.Pregex, str], assertion: _Union[_pre.Pregex, str]):
+    def __init__(self, match: _Union[_pre.Pregex, str], *assertions: _Union[_pre.Pregex, str]):
         '''
-        Matches pattern ``match`` only if it is followed by pattern \
-        ``assertion``, without the latter being included into the match.
+        Matches pattern ``match`` only if it is directly followed \
+        by all of the provided ``assertion`` patterns.
 
         :param Pregex | str match: A Pregex instance or string \
             representing the `match` pattern.
-        :param Pregex | str assertion: A Pregex instance or string \
-            representing the `assertion` pattern.
+        :param Pregex | str \*assertions: One or more patterns, all of which must \
+            come right after pattern ``match`` in order for it to be considered a match.
 
+        :raises NotEnoughArgumentsException: No assertion patterns were provided.
         :raises InvalidArgumentTypeException: At least one of the provided arguments \
             is neither a ``Pregex`` instance nor a string.
 
         :note: The resulting pattern cannot have a repeating quantifier applied to it.
         '''
-        super().__init__(match, assertion, lambda pre1, pre2: pre1.followed_by(pre2))
+        super().__init__((match, *assertions), lambda pre1, pre2: pre1.followed_by(pre2))
 
 
-class PrecededBy(__PositiveLookaround):
+class PrecededBy(__Lookaround):
     '''
-    Matches pattern ``match`` only if it is preceded by pattern \
-    ``assertion``, without the latter being included into the match.
+    Matches pattern ``match`` only if it is directly preceded \
+    by all of the provided ``assertion`` patterns.
 
     :param Pregex | str match: A Pregex instance or string \
         representing the `match` pattern.
-    :param Pregex | str assertion: A Pregex instance or string \
-        representing the `assertion` pattern.
+    :param Pregex | str \*assertions: One or more patterns, all of which must \
+        come right before pattern ``match`` in order for it to be considered a match.
 
+    :raises NotEnoughArgumentsException: No assertion patterns were provided.
     :raises InvalidArgumentTypeException: At least one of the provided arguments \
         is neither a ``Pregex`` instance nor a string.
     :raises NonFixedWidthPatternException: Parameter ``assertion`` \
@@ -307,16 +286,17 @@ class PrecededBy(__PositiveLookaround):
     :note: The resulting pattern cannot have a repeating quantifier applied to it.
     '''
 
-    def __init__(self, match: _Union[_pre.Pregex, str], assertion: _Union[_pre.Pregex, str]):
+    def __init__(self, match: _Union[_pre.Pregex, str], *assertions: _Union[_pre.Pregex, str]):
         '''
-        Matches pattern ``match`` only if it is preceded by pattern \
-        ``assertion``, without the latter being included into the match.
+        Matches pattern ``match`` only if it is directly preceded \
+        by all of the provided ``assertion`` patterns.
 
         :param Pregex | str match: A Pregex instance or string \
             representing the `match` pattern.
-        :param Pregex | str assertion: A Pregex instance or string \
-            representing the `assertion` pattern.
+        :param Pregex | str \*assertions: One or more patterns, all of which must \
+            come right before pattern ``match`` in order for it to be considered a match.
 
+        :raises NotEnoughArgumentsException: No assertion patterns were provided.
         :raises InvalidArgumentTypeException: At least one of the provided arguments \
             is neither a ``Pregex`` instance nor a string.
         :raises NonFixedWidthPatternException: Parameter ``assertion`` \
@@ -324,19 +304,21 @@ class PrecededBy(__PositiveLookaround):
 
         :note: The resulting pattern cannot have a repeating quantifier applied to it.
         '''
-        super().__init__(match, assertion, lambda pre1, pre2: pre1.preceded_by(pre2))
+        super().__init__((match, *assertions), lambda pre1, pre2: pre1.preceded_by(pre2))
 
 
-class EnclosedBy(__PositiveLookaround):
+class EnclosedBy(__Lookaround):
     '''
-    Matches pattern ``match`` only if it is both preceded and followed \
-    by pattern ``assertion``, without the latter being included into the match.
+    Matches pattern ``match`` only if it is both directly preceded \
+    and followed by all of the provided ``assertion`` patterns.
 
     :param Pregex | str match: A Pregex instance or string \
         representing the `match` pattern.
-    :param Pregex | str assertion: A Pregex instance or string \
-        representing the *assertion* pattern.
+    :param Pregex | str \*assertions: One or more patterns, all of which must \
+        come both right before and right after pattern ``match`` in order for \
+        it to be considered a match.
 
+    :raises NotEnoughArgumentsException: No assertion patterns were provided.
     :raises InvalidArgumentTypeException: At least one of the provided arguments \
         is neither a ``Pregex`` instance nor a string.
     :raises NonFixedWidthPatternException: Parameter ``assertion`` \
@@ -345,16 +327,18 @@ class EnclosedBy(__PositiveLookaround):
     :note: The resulting pattern cannot have a repeating quantifier applied to it.
     '''
 
-    def __init__(self, match: _Union[_pre.Pregex, str], assertion: _Union[_pre.Pregex, str]):
+    def __init__(self, match: _Union[_pre.Pregex, str], *assertions: _Union[_pre.Pregex, str]):
         '''
-        Matches pattern ``match`` only if it is both preceded and followed \
-        by pattern ``assertion``, without the latter being included into the match.
+        Matches pattern ``match`` only if it is both directly preceded \
+        and followed by all of the provided ``assertion`` patterns.
 
         :param Pregex | str match: A Pregex instance or string \
             representing the `match` pattern.
-        :param Pregex | str assertion: A Pregex instance or string \
-            representing the *assertion* pattern.
+        :param Pregex | str \*assertions: One or more patterns, all of which must \
+            come both right before and right after pattern ``match`` in order for \
+            it to be considered a match.
 
+        :raises NotEnoughArgumentsException: No assertion patterns were provided.
         :raises InvalidArgumentTypeException: At least one of the provided arguments \
             is neither a ``Pregex`` instance nor a string.
         :raises NonFixedWidthPatternException: Parameter ``assertion`` \
@@ -362,17 +346,17 @@ class EnclosedBy(__PositiveLookaround):
 
         :note: The resulting pattern cannot have a repeating quantifier applied to it.
         '''
-        super().__init__(match, assertion, lambda pre1, pre2: pre1.enclosed_by(pre2))
+        super().__init__((match, *assertions), lambda pre1, pre2: pre1.enclosed_by(pre2))
 
 
-class NotFollowedBy(__NegativeLookaround):
+class NotFollowedBy(__Lookaround):
     '''
-    Matches pattern ``match`` only if it is not followed by any one of \
-    the provided ``assertion`` patterns.
+    Matches pattern ``match`` only if it is not directly followed by \
+    any one of the provided ``assertions`` patterns.
 
     :param Pregex | str match: The pattern that is to be matched.
     :param Pregex | str \*assertions: One or more patterns, none of which must \
-        come right after ``match`` in order for it to be considered a match.
+        come right after pattern ``match`` in order for it to be considered a match.
 
     :raises NotEnoughArgumentsException: No assertion patterns were provided.
     :raises InvalidArgumentTypeException: At least one of the provided arguments \
@@ -383,12 +367,12 @@ class NotFollowedBy(__NegativeLookaround):
 
     def __init__(self, match: _Union[_pre.Pregex, str], *assertions: _Union[_pre.Pregex, str]):
         '''
-        Matches pattern ``match`` only if it is not followed by any one of \
-        the provided ``assertion`` patterns.
+        Matches pattern ``match`` only if it is not directly followed by \
+        any one of the provided ``assertions`` patterns.
 
         :param Pregex | str match: The pattern that is to be matched.
         :param Pregex | str \*assertions: One or more patterns, none of which must \
-            come right after ``match`` in order for it to be considered a match.
+            come right after pattern ``match`` in order for it to be considered a match.
 
         :raises NotEnoughArgumentsException: No assertion patterns were provided.
         :raises InvalidArgumentTypeException: At least one of the provided arguments \
@@ -400,14 +384,14 @@ class NotFollowedBy(__NegativeLookaround):
             lambda pre1, pre2: pre1.not_followed_by(pre2))
 
 
-class NotPrecededBy(__NegativeLookaround):
+class NotPrecededBy(__Lookaround):
     '''
-    Matches pattern ``match`` only if it is not preceded by any one of \
-    the provided ``assertion`` patterns.
+    Matches pattern ``match`` only if it is not directly preceded by \
+    any one of the provided ``assertions`` patterns.
 
     :param Pregex | str match: The pattern that is to be matched.
     :param Pregex | str \*assertions: One or more patterns, none of which must \
-        come right before ``match`` in order for it to be considered a match.
+        come right before pattern ``match`` in order for it to be considered a match.
 
     :raises NotEnoughArgumentsException: No assertion patterns were provided.
     :raises InvalidArgumentTypeException: At least one of the provided arguments \
@@ -420,12 +404,12 @@ class NotPrecededBy(__NegativeLookaround):
 
     def __init__(self, match: _Union[_pre.Pregex, str], *assertions: _Union[_pre.Pregex, str]):
         '''
-        Matches pattern ``match`` only if it is not preceded by any one of \
-        the provided ``assertion`` patterns.
+        Matches pattern ``match`` only if it is not directly preceded by \
+        any one of the provided ``assertions`` patterns.
 
         :param Pregex | str match: The pattern that is to be matched.
         :param Pregex | str \*assertions: One or more patterns, none of which must \
-            come right before ``match`` in order for it to be considered a match.
+            come right before pattern ``match`` in order for it to be considered a match.
 
         :raises NotEnoughArgumentsException: No assertion patterns were provided.
         :raises InvalidArgumentTypeException: At least one of the provided arguments \
@@ -439,14 +423,15 @@ class NotPrecededBy(__NegativeLookaround):
             lambda pre1, pre2: pre1.not_preceded_by(pre2))
 
 
-class NotEnclosedBy(__NegativeLookaround):
+class NotEnclosedBy(__Lookaround):
     '''
-    Matches pattern ``match`` only if it is neither preceded nor followed \
-    by any one of the provided ``assertion`` patterns.
+    Matches pattern ``match`` only if it is neither directly preceded \
+    nor followed by any one of the provided ``assertions`` patterns.
 
     :param Pregex | str match: The pattern that is to be matched.
     :param Pregex | str \*assertions: One or more patterns, none of which must \
-        come right before ``match`` in order for it to be considered a match.
+        come either right before or right after pattern ``match`` in order for \
+        it to be considered a match.
 
     :raises NotEnoughArgumentsException: No assertion patterns were provided.
     :raises InvalidArgumentTypeException: At least one of the provided arguments \
@@ -459,12 +444,13 @@ class NotEnclosedBy(__NegativeLookaround):
 
     def __init__(self, match: _Union[_pre.Pregex, str], *assertions: _Union[_pre.Pregex, str]):
         '''
-        Matches pattern ``match`` only if it is neither preceded nor followed \
-        by any one of the provided ``assertion`` patterns.
+        Matches pattern ``match`` only if it is neither directly preceded \
+        nor followed by any one of the provided ``assertions`` patterns.
 
         :param Pregex | str match: The pattern that is to be matched.
         :param Pregex | str \*assertions: One or more patterns, none of which must \
-            come right before ``match`` in order for it to be considered a match.
+            come either right before or right after pattern ``match`` in order for \
+            it to be considered a match.
 
         :raises NotEnoughArgumentsException: No assertion patterns were provided.
         :raises InvalidArgumentTypeException: At least one of the provided arguments \
